@@ -279,7 +279,7 @@ class PHP_LexerGenerator_Parser#line 171 "Parser.php"
                     $match = false;
                     foreach ($yy_yymore_patterns[' . $this->token . '] as $index => $rule) {
                         if (preg_match(\'/\' . $rule . \'/' . $this->patternFlags . '\',
-                                ' . $this->input . ', $yymatches, null, ' . $this->counter . ')) {
+                                ' . $this->input . ', $yymatches, 0, ' . $this->counter . ')) {
                             if (strlen($yysubmatches[0]) < 200) {
                                 $yymatches = preg_grep("/(.|\s)+/", $yysubmatches);
                             } else {
@@ -348,22 +348,26 @@ class PHP_LexerGenerator_Parser#line 171 "Parser.php"
         $pattern .= '/' . $this->patternFlags;
         fwrite($this->out, '
         if (!isset($this->yy_global_pattern' . $ruleindex . ')) {
-            $this->yy_global_pattern' . $ruleindex . ' = "' . $pattern . 'isS";
+            $this->yy_global_pattern' . $ruleindex . ' = $this->replace("' . $pattern . 'isS");
         }
-        if (!isset($this->dataLenght)) {
-            $this->dataLenght = strlen(' . $this->input . ');
+        if (!isset($this->dataLength)) {
+            $this->dataLength = strlen(' . $this->input . ');
         }
-        if (' . $this->counter . ' >=  $this->dataLenght) {
+        if (' . $this->counter . ' >=  $this->dataLength) {
             return false; // end of input
         }
         ');
         fwrite($this->out, '
         do {
-            if (preg_match($this->yy_global_pattern' . $ruleindex . ',' . $this->input . ', $yymatches, null, ' .
+            if (preg_match($this->yy_global_pattern' . $ruleindex . ',' . $this->input . ', $yymatches, 0, ' .
              $this->counter .
                     ')) {
-                 $yymatches = array_filter($yymatches);
-                 if (empty($yymatches)) {
+                if (!isset($yymatches[ 0 ][1])) {
+                   $yymatches = preg_grep("/(.|\s)+/", $yymatches);
+                } else {
+                    $yymatches = array_filter($yymatches);
+                }
+                if (empty($yymatches)) {
                     throw new Exception(\'Error: lexing failed because a rule matched\' .
                         \' an empty string.  Input "\' . substr(' . $this->input . ',
                         ' . $this->counter . ', 5) . \'... state ' . $statename . '\');
@@ -384,7 +388,7 @@ class PHP_LexerGenerator_Parser#line 171 "Parser.php"
                 } elseif ($r === false) {
                     ' . $this->counter . ' += strlen(' . $this->value . ');
                     ' . $this->line . ' += substr_count(' . $this->value . ', "\n");
-                    if (' . $this->counter . ' >=  $this->dataLenght) {
+                    if (' . $this->counter . ' >=  $this->dataLength) {
                         return false; // end of input
                     }
                     // skip this token
@@ -433,7 +437,7 @@ class PHP_LexerGenerator_Parser#line 171 "Parser.php"
                     } elseif ($r === false) {
                         ' . $this->counter . ' += strlen(' . $this->value . ');
                         ' . $this->line . ' += substr_count(' . $this->value . ', "\n");
-                        if (' . $this->counter . ' >=  $this->dataLenght) {
+                        if (' . $this->counter . ' >=  $this->dataLength) {
                             return false; // end of input
                         }
                         // skip this token
